@@ -20,5 +20,5 @@ class SESEmailBackend(EmailBackend):
                 ]
             },
             Template=f'pythonit-pastaporto-{template}',
-            TemplateData=json.dumps(variables) if variables else {}
+            TemplateData=json.dumps(variables if variables else {})
         )
